@@ -1,5 +1,5 @@
 /*
- * Copyright 2007      by Sascha Hlusiak. <saschahlusiak@freedesktop.org>     
+ * Copyright 2007-2008 by Sascha Hlusiak. <saschahlusiak@freedesktop.org>     
  *                                                                            
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is  hereby granted without fee, provided that
@@ -24,9 +24,6 @@
 #ifndef __JSTK_OPTIONS_H_INCLUDED__
 #define __JSTK_OPTIONS_H_INCLUDED__
 
-int jstkGetButtonNumberInMap(JoystickDevPtr priv,
-                             int buttonnumber);
-
 void jstkParseButtonOption(const char* org, 
                            JoystickDevPtr priv,
                            int number,
